<?php

namespace WPIS;

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

class Updater {

    public function __construct() {
        add_filter('pre_set_site_transient_update_plugins', [$this, 'checkForUpdate']);
        add_filter('plugins_api', [$this, 'getInfo'], 20, 3);
    }

    public function checkForUpdate($checked_data){

        global $wp_version;

        $plugin_slug = 'wp-immo-sync';
        $api_url = 'https://wp.immosync.com/update/version.php';

        //Comment out these two lines during testing.
        // if (empty($checked_data->checked))
        //     return $checked_data;

        $args = array(
            'slug' => $plugin_slug,
            'version' => $checked_data->checked[$plugin_slug .'/'. $plugin_slug .'.php'],
        );

        $request_string = array(
            'body' => array(
                'action' => 'basic_check',
                'request' => serialize($args),
                'api-key' => md5(get_bloginfo('url'))
            ),
            'user-agent' => 'WordPress/' . $wp_version . '; ' . get_bloginfo('url')
        );

        // Start checking for an update
        $raw_response = wp_remote_post($api_url, $request_string);

        if (!is_wp_error($raw_response) && ($raw_response['response']['code'] == 200))
            $response = unserialize($raw_response['body']);

        if (is_object($response) && !empty($response)) // Feed the update data into WP updater
            $checked_data->response[$plugin_slug .'/'. $plugin_slug .'.php'] = $response;

        return $checked_data;
    }

    public function getInfo( $res, $action, $args ){

        if( 'plugin_information' !== $action ) {
            return false;
        }

        $plugin_slug = 'wp-immo-sync';

        if( $plugin_slug !== $args->slug ) {
            return false;
        }

        // if( false == $remote = get_transient( 'wpis_update_' . $plugin_slug ) ) {

            $remote = wp_remote_get( 'https://wp.immosync.com/update/info.json', [
                'timeout' => 10,
                'headers' => [
                    'Accept' => 'application/json'
                ]
            ]);

            if ( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
                set_transient( 'wpis_update_' . $plugin_slug, $remote, 43200 ); // 12 hours cache
            }

        // }

        if( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {

            $remote = json_decode( $remote['body'] );
            $res = (object) [];
            $res->name = $remote->name;
            $res->slug = $plugin_slug;
            $res->version = $remote->version;
            $res->tested = $remote->tested;
            $res->requires = $remote->requires;
            $res->author = $remote->author;
            $res->download_link = $remote->download_url;
            $res->trunk = $remote->download_url;
            $res->requires_php = $remote->requires_php;
            $res->last_updated = $remote->last_updated;
            $res->sections = array(
                'description' => $remote->sections->description,
                'installation' => $remote->sections->installation,
                'changelog' => $remote->sections->changelog
            );

            // in case you want the screenshots tab, use the following HTML format for its content:
            // <ol><li><a href="IMG_URL" target="_blank"><img src="IMG_URL" alt="CAPTION" /></a><p>CAPTION</p></li></ol>
            if( !empty( $remote->sections->screenshots ) ) {
                $res->sections['screenshots'] = $remote->sections->screenshots;
            }

            $res->banners = [
                'low' => $remote->banners->low,
                'high' => $remote->banners->high
            ];
            return $res;

        }

        return false;

    }
}

new Updater();